@@ -1,6 +1,6 @@
-/*  xfce4
+/*  $Id: mcs_client.h 4135 2004-09-13 20:31:39Z jasper $
  *
- *  Copyright (C) 2002 Jasper Huijsmans <huysmans@users.sourceforge.net>
+ *  Copyright 2002-2004 Jasper Huijsmans <jasper@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,12 @@
 #ifndef __XFCE_MCSCLIENT_H
 #define __XFCE_MCSCLIENT_H
 
-void mcs_watch_xfce_channel (void);
+#include <gmodule.h>
 
-void mcs_stop_watch (void);
+G_MODULE_IMPORT void mcs_watch_xfce_channel (void);
 
-void mcs_dialog (const char *channel);
+G_MODULE_IMPORT void mcs_stop_watch (void);
+
+G_MODULE_IMPORT void mcs_dialog (const char *channel);
 
 #endif /* __XFCE_MCSCLIENT_H */
