@@ -1,8 +1,8 @@
-/*  clock.c
+/*  $Id: clock.c 4355 2005-03-07 20:51:48Z jasper $
  *
- *  Copyright (C) 2002 Jasper Huijsmans(huysmans@users.sourceforge.net)
- *                     Xavier Maillard (zedek@fxgsproject.org)
- *                     Olivier Fourdan (fourdan@xfce.org)
+ *  Copyright 2002,2004 Jasper Huijsmans(jasper@xfce.org)
+ *                      Olivier Fourdan (fourdan@xfce.org)
+ *                      Xavier Maillard (zedek@fxgsproject.org)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,43 +41,17 @@
 #include <unistd.h>
 #endif
 
-#include <libxfce4util/i18n.h>
+#include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/xfce_clock.h>
 
 #include <panel/global.h>
 #include <panel/controls.h>
 #include <panel/icons.h>
 #include <panel/plugins.h>
+#include <panel/groups.h>
 
 #define BORDER 6
 
-/* Clock tooltip - From xfce3 */
-/* FIXME: Find another place for that */
-static char *day_names[] = {
-    N_("Sunday"),
-    N_("Monday"),
-    N_("Tuesday"),
-    N_("Wednesday"),
-    N_("Thursday"),
-    N_("Friday"),
-    N_("Saturday")
-};
-
-static char *month_names[] = {
-    N_("January"),
-    N_("February"),
-    N_("March"),
-    N_("April"),
-    N_("May"),
-    N_("June"),
-    N_("July"),
-    N_("August"),
-    N_("September"),
-    N_("October"),
-    N_("November"),
-    N_("December")
-};
-
 /*  Clock module
  *  ------------
 */
@@ -115,6 +89,79 @@ typedef struct
 }
 ClockDialog;
 
+/* start xfcalendar or send a client message
+ * NOTE: keep message format in sync with xfcalendar */
+
+static gboolean
+popup_xfcalendar (GtkWidget * widget)
+{
+    GdkAtom atom;
+    Window xwindow;
+
+    /* send message to xfcalendar if it is running */
+    atom = gdk_atom_intern ("_XFCE_CALENDAR_RUNNING", FALSE);
+    if ((xwindow = XGetSelectionOwner (GDK_DISPLAY (),
+				       gdk_x11_atom_to_xatom (atom))) != None)
+    {
+	char msg[20];
+	const char *fmt = "%lx:%s";
+	Window xid = GDK_WINDOW_XID (widget->window);
+	GdkEventClient gev;
+
+	/* popup in the same direction as menus */
+	switch (groups_get_arrow_direction ())
+	{
+	    case GTK_ARROW_UP:
+		sprintf (msg, fmt, xid, "up");
+		break;
+	    case GTK_ARROW_DOWN:
+		sprintf (msg, fmt, xid, "down");
+		break;
+	    case GTK_ARROW_LEFT:
+		sprintf (msg, fmt, xid, "left");
+		break;
+	    case GTK_ARROW_RIGHT:
+		sprintf (msg, fmt, xid, "right");
+		break;
+	    default:
+		return FALSE;
+	}
+
+	gev.type = GDK_CLIENT_EVENT;
+	gev.window = widget->window;
+	gev.send_event = TRUE;
+	gev.message_type =
+	    gdk_atom_intern ("_XFCE_CALENDAR_TOGGLE_HERE", FALSE);
+	gev.data_format = 8;
+	strcpy (gev.data.b, msg);
+
+	gdk_event_send_client_message ((GdkEvent *) & gev,
+				       (GdkNativeWindow) xwindow);
+	gdk_flush ();
+
+	return TRUE;
+    }
+    else 
+    {
+	exec_cmd_silent ("xfcalendar", FALSE, FALSE);
+    exec_cmd_silent ("xfcalendar", FALSE, FALSE); /* actually only RAISE */
+    }
+
+    return FALSE;
+}
+
+static gboolean
+on_button_press_event_cb (GtkWidget * widget,
+			  GdkEventButton * event, Control * control)
+{
+    if (event->button == 1)
+    {
+	return popup_xfcalendar (control->base);
+    }
+
+    return FALSE;
+}
+
 /* creation and destruction */
 gboolean
 clock_date_tooltip (GtkWidget * widget)
@@ -122,27 +169,45 @@ clock_date_tooltip (GtkWidget * widget)
     time_t ticks;
     struct tm *tm;
     static gint mday = -1;
-    static gint wday = -1;
-    static gint mon = -1;
-    static gint year = -1;
     char date_s[255];
+    char *utf8date = NULL;
 
-    g_return_val_if_fail (widget != NULL, FALSE);
-    g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+    g_return_val_if_fail (widget != NULL, TRUE);
+    g_return_val_if_fail (GTK_IS_WIDGET (widget), TRUE);
 
     ticks = time (0);
     tm = localtime (&ticks);
-    if ((mday != tm->tm_mday) || (wday != tm->tm_wday) || (mon != tm->tm_mon)
-	|| (year != tm->tm_year))
+
+    if (mday != tm->tm_mday)
     {
 	mday = tm->tm_mday;
-	wday = tm->tm_wday;
-	mon = tm->tm_mon;
-	year = tm->tm_year;
-	snprintf (date_s, 255, "%s, %u %s %u", _(day_names[wday]), mday,
-		  _(month_names[mon]), year + 1900);
-	add_tooltip (widget, _(date_s));
+	/* Use format characters from strftime(3)
+	 * to get the proper string for your locale.
+	 * I used these:
+	 * %A  : full weekday name
+	 * %d  : day of the month
+	 * %B  : full month name
+	 * %Y  : four digit year
+	 */
+	strftime (date_s, 255, _("%A, %d %B %Y"), tm);
+
+	/* Conversion to utf8
+	 * patch by Oliver M. Bolzer <oliver@fakeroot.net>
+	 */
+        if (!g_utf8_validate (date_s, -1, NULL))
+            utf8date = g_locale_to_utf8 (date_s, -1, NULL, NULL, NULL);
+        
+	if (utf8date)
+	{
+	    add_tooltip (widget, utf8date);
+	    g_free (utf8date);
+	}
+        else
+        {
+            add_tooltip (widget, date_s);
+        }
     }
+
     return TRUE;
 }
 
@@ -166,6 +231,10 @@ clock_new (void)
 	g_timeout_add (60000, (GSourceFunc) clock_date_tooltip,
 		       clock->eventbox);
 
+    /* callback for calendar popup */
+    g_signal_connect (G_OBJECT (clock->eventbox), "button-press-event",
+		      G_CALLBACK (on_button_press_event_cb), clock);
+
     return clock;
 }
 
@@ -177,7 +246,10 @@ clock_free (Control * control)
     g_return_if_fail (clock != NULL);
 
     if (clock->timeout_id)
+    {
 	g_source_remove (clock->timeout_id);
+        clock->timeout_id = 0;
+    }
 
     g_free (clock);
 }
@@ -544,19 +616,19 @@ clock_restore_backup (ClockDialog * cd)
 /* clock options box */
 void
 clock_create_options (Control * control, GtkContainer * container,
-		   GtkWidget * done)
+		      GtkWidget * done)
 {
     GtkWidget *vbox;
     GtkSizeGroup *sg = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
     ClockDialog *cd;
 
+    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+
     cd = g_new0 (ClockDialog, 1);
 
     cd->clock = control->data;
     cd->dialog = gtk_widget_get_toplevel (done);
 
-/*    clock_create_backup (cd);*/
-
     g_signal_connect_swapped (cd->dialog, "destroy-event",
 			      G_CALLBACK (g_free), cd);
 
@@ -592,9 +664,13 @@ create_clock_control (Control * control)
     return TRUE;
 }
 
+/* calculate position of calendar popup */
+
 G_MODULE_EXPORT void
 xfce_control_class_init (ControlClass * cc)
 {
+    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+
     cc->name = "clock";
     cc->caption = _("Xfce Clock");
 
@@ -608,6 +684,8 @@ xfce_control_class_init (ControlClass * cc)
     cc->create_options = clock_create_options;
 
     cc->set_size = clock_set_size;
+
+    control_class_set_unique (cc, TRUE);
 }
 
 /* macro defined in plugins.h */
