@@ -1,6 +1,6 @@
-/*  xfce4
+/*  $Id: xfce_settings.h 4117 2004-08-30 12:55:43Z jasper $
  *
- *  Copyright (C) 2002 Jasper Huijsmans <huysmans@users.sourceforge.net>
+ *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,21 +31,9 @@ enum
     XFCE_POPUPPOSITION,
     XFCE_THEME,
     XFCE_AUTOHIDE,
-    XFCE_POSITION,
     XFCE_OPTIONS
 };
 
-enum
-{
-    XFCE_POSITION_BOTTOM,
-    XFCE_POSITION_TOP,
-    XFCE_POSITION_LEFT,
-    XFCE_POSITION_RIGHT,
-    XFCE_POSITION_SAVE,
-    XFCE_POSITION_RESTORE,
-    XFCE_POSITION_NONE,
-};
-
 static char *xfce_settings_names[] = {
     "orientation",
     "layer",
@@ -53,7 +41,6 @@ static char *xfce_settings_names[] = {
     "popupposition",
     "theme",
     "autohide",
-    "position"
 };
 
 #endif /* __XFCE_SETTINGS_H */
